@@ -317,9 +317,12 @@ class waveAnalysis(object):
                     # Get desired time interval
                     time_var = ncs.variables["TIME"]
                     tt = ncs.variables["TIME"][:]
-                    timing = netCDF4.num2date(tt, time_var.units
-                                             only_use_cftime_datetimes=False,
-                                             only_use_python_datetimes=True)
+                    timing = netCDF4.num2date(
+                        tt,
+                        time_var.units,
+                        only_use_cftime_datetimes=False,
+                        only_use_python_datetimes=True,
+                    )
                     self.time_units = time_var.units
                     timebound = np.where(
                         np.logical_and(
@@ -331,11 +334,11 @@ class waveAnalysis(object):
                     if len(reduceID) > 0:
                         keysname = list(ncs.variables.keys())
                         ws = ncs.variables["WSPD_CAL"][:]
-                        if 'SWH_KU_CAL' in keysname:
+                        if "SWH_KU_CAL" in keysname:
                             wh = ncs.variables["SWH_KU_CAL"][:]
                             qc = ncs.variables["SWH_KU_quality_control"][:]
                             back = ncs.variables["SIG0_KU"][:]
-                        elif 'SWH_KA_CAL' in keysname:
+                        elif "SWH_KA_CAL" in keysname:
                             wh = ncs.variables["SWH_KA_CAL"][:]
                             qc = ncs.variables["SWH_KA_quality_control"][:]
                             back = ncs.variables["SIG0_KA"][:]
@@ -566,13 +569,13 @@ class waveAnalysis(object):
             color="r",
             s=markersize,
             edgecolor="black",
-            linewidth="0.5",
+            linewidth=0.5,
             alpha=1,
             transform=ccrs.PlateCarree(),
             zorder=5,
         )
 
-        geodetic_transform = ccrs.Geodetic()._as_mpl_transform(ax)
+        geodetic_transform = ccrs.PlateCarree()._as_mpl_transform(ax)
         text_transform = offset_copy(geodetic_transform, units="dots", y=-30)
 
         cycloneyear = self.cyclone["datetime"].dt.year
@@ -619,7 +622,7 @@ class waveAnalysis(object):
                 color="navy",
                 s=markersize,
                 edgecolor="black",
-                linewidth="0.5",
+                linewidth=0.5,
                 alpha=1,
                 transform=ccrs.PlateCarree(),
                 zorder=10,
@@ -633,8 +636,8 @@ class waveAnalysis(object):
             alpha=0.5,
             linestyle="--",
         )
-        gl.xlabels_top = False
-        gl.ylabels_left = False
+        gl.top_labels = False
+        gl.left_labels = False
         gl.xformatter = LONGITUDE_FORMATTER
         gl.yformatter = LATITUDE_FORMATTER
 
@@ -690,18 +693,18 @@ class waveAnalysis(object):
         if extent is None:
             ax.set_extent(
                 [self.lonmin, self.lonmax, self.latmin, self.latmax],
-                crs=ccrs.Geodetic(),
+                crs=ccrs.PlateCarree(),
             )
         else:
             ax.set_extent(
-                [extent[0], extent[1], extent[2], extent[3]], crs=ccrs.Geodetic()
+                [extent[0], extent[1], extent[2], extent[3]], crs=ccrs.PlateCarree()
             )
 
         # Add the Stamen data
         ax.add_image(stamen_terrain, zoom)
 
         ax.set_title(title)
-        # ax.coastlines(resolution="10m")
+        ax.coastlines(resolution="10m")
 
         ax.scatter(
             [self.lon],
@@ -710,14 +713,14 @@ class waveAnalysis(object):
             color="coral",
             s=markersize,
             edgecolor="black",
-            linewidth="0.5",
+            linewidth=0.5,
             alpha=0.7,
-            transform=ccrs.Geodetic(),
+            transform=ccrs.PlateCarree(),
         )
 
         # Use the cartopy interface to create a matplotlib transform object
         # for the Geodetic coordinate system.
-        geodetic_transform = ccrs.Geodetic()._as_mpl_transform(ax)
+        geodetic_transform = ccrs.PlateCarree()._as_mpl_transform(ax)
         text_transform = offset_copy(geodetic_transform, units="dots", x=-12)
 
         # Cyclone track
@@ -747,9 +750,9 @@ class waveAnalysis(object):
                 color="navy",
                 s=100,
                 edgecolor="black",
-                linewidth="0.5",
+                linewidth=0.5,
                 alpha=0.7,
-                transform=ccrs.Geodetic(),
+                transform=ccrs.PlateCarree(),
             )
             ax.text(
                 lon_city,
@@ -787,8 +790,8 @@ class waveAnalysis(object):
             alpha=0.5,
             linestyle="--",
         )
-        gl.xlabels_top = False
-        gl.ylabels_left = False
+        gl.top_labels = False
+        gl.left_labels = False
         gl.xformatter = LONGITUDE_FORMATTER
         gl.yformatter = LATITUDE_FORMATTER
 
@@ -957,9 +960,12 @@ class waveAnalysis(object):
         self.speed = self.waveGroupVelocity(self.T)
         self.power1 = self.waveEnergyFlux(self.wh, self.T)
 
-        sort_time = netCDF4.num2date(self.times.astype(float), self.time_units,
-                                     only_use_cftime_datetimes=False,
-                                     only_use_python_datetimes=True)
+        sort_time = netCDF4.num2date(
+            self.times.astype(float),
+            self.time_units,
+            only_use_cftime_datetimes=False,
+            only_use_python_datetimes=True,
+        )
 
         wavedf = pd.DataFrame(
             data={
@@ -1410,17 +1416,17 @@ class waveAnalysis(object):
             if extent is None:
                 ax.set_extent(
                     [self.lonmin, self.lonmax, self.latmin, self.latmax],
-                    crs=ccrs.Geodetic(),
+                    crs=ccrs.PlateCarree(),
                 )
             else:
                 ax.set_extent(
-                    [extent[0], extent[1], extent[2], extent[3]], crs=ccrs.Geodetic()
+                    [extent[0], extent[1], extent[2], extent[3]], crs=ccrs.PlateCarree()
                 )
 
             ax.add_image(stamen_terrain, zoom)
             ax.coastlines(resolution="10m")
 
-            geodetic_transform = ccrs.Geodetic()._as_mpl_transform(ax)
+            geodetic_transform = ccrs.PlateCarree()._as_mpl_transform(ax)
             text_transform = offset_copy(geodetic_transform, units="dots", x=-12)
 
             # Cyclone track
@@ -1443,7 +1449,7 @@ class waveAnalysis(object):
                 color="w",
                 s=markersize * 0.5,
                 edgecolor="black",
-                linewidth="0.5",
+                linewidth=0.5,
                 alpha=1,
                 transform=ccrs.PlateCarree(),
                 zorder=5,
@@ -1465,7 +1471,7 @@ class waveAnalysis(object):
                 s=markersize * 3,
                 color="k",
                 edgecolor="black",
-                linewidth="1",
+                linewidth=1,
                 alpha=1,
                 transform=ccrs.PlateCarree(),
                 zorder=5,
@@ -1480,7 +1486,7 @@ class waveAnalysis(object):
                             marker="o",
                             s=markersize * 2,
                             edgecolor="k",
-                            linewidth="1",
+                            linewidth=1,
                             alpha=1,
                             transform=ccrs.PlateCarree(),
                             zorder=5,
@@ -1498,9 +1504,9 @@ class waveAnalysis(object):
                     color="navy",
                     s=100,
                     edgecolor="black",
-                    linewidth="0.5",
+                    linewidth=0.5,
                     alpha=0.7,
-                    transform=ccrs.Geodetic(),
+                    transform=ccrs.PlateCarree(),
                 )
 
                 ax.text(
@@ -1544,8 +1550,8 @@ class waveAnalysis(object):
                 alpha=0.5,
                 linestyle="--",
             )
-            gl.xlabels_top = False
-            gl.ylabels_left = False
+            gl.top_labels = False
+            gl.left_labels = False
             gl.xformatter = LONGITUDE_FORMATTER
             gl.yformatter = LATITUDE_FORMATTER
 
